@@ -1377,7 +1377,7 @@ class LaharFlowData(object):
             ('longitude', np.float64),
             (var, np.float64)]
 
-        data_clipped = np.full((len(indx),), np.nan, dtype=dt)
+        data_clipped = np.full((indx.shape), np.nan, dtype=dt)
 
         data_clipped[var] = data[var][indx]
         data_clipped['x_distance'] = data['x_distance'][indx]
